@@ -35,7 +35,7 @@ import java.util.*;
  *
  * @author Paul Liu
  */
-public class MyApplet extends JApplet {
+public class MyApplet extends Panel {
 
     private JPanel cards = null;
     private java.util.logging.Logger logger = null;
@@ -56,13 +56,18 @@ public class MyApplet extends JApplet {
     private JSlider utilitiesExtruderHeightPanel = null;
 
     private ResourceBundle resources = ResourceBundle.getBundle("ucrpf1host");
+
+    public MyApplet() {
+	super();
+	init();
+    }
     
     /**
      * init the UI layout and connect the ActionListeners
      */
     public void init() {
-	super.init();
-	Container cp = getContentPane();
+	//super.init();
+	Container cp = this;
 
 	this.logger = java.util.logging.Logger.getLogger(MyApplet.loggerName);
 	this.logger.setLevel(java.util.logging.Level.INFO);
@@ -341,7 +346,7 @@ public class MyApplet extends JApplet {
 	preheatTemperatureLabelGC.anchor = GridBagConstraints.EAST;
 	centerPanel.add(preheatTemperatureLabel, preheatTemperatureLabelGC);
 
-	JSpinner preheatTemperature = new JSpinner (new SpinnerNumberModel(new Integer((int)Math.round(GlobalSettings.getInstance().getExtruderPreheatTemperature())), new Integer(100), new Integer(260), new Integer(1)));
+	JSpinner preheatTemperature = new JSpinner (new SpinnerNumberModel(Integer.valueOf((int)Math.round(GlobalSettings.getInstance().getExtruderPreheatTemperature())), Integer.valueOf(100), Integer.valueOf(260), Integer.valueOf(1)));
 	GridBagConstraints preheatTemperatureGC = new GridBagConstraints();
 	preheatTemperatureGC.gridx = 2;
 	preheatTemperatureGC.gridy = 1;
@@ -632,7 +637,7 @@ public class MyApplet extends JApplet {
 	    pf1Device.close(5000);
 	    pf1Device = null;
 	}
-	super.stop();
+	//super.stop();
     }
 
     /**
